@@ -1,10 +1,10 @@
 import logging
 from typing import Optional, List
 from numpy import int32
-from sqlalchemy import create_engine, MetaData, Table, select, and_
-import sqlalchemy
+from sqlalchemy import create_engine, MetaData, Table
 from sqlalchemy.pool import NullPool
 import pandas as pd
+import sqlalchemy
 
 
 
