@@ -8,7 +8,7 @@ import numpy as np
 
 __all__ = ['create_address_pivot','clean_brackets_from_list','clean_brackets_from_string','extract_info_from_summaries']
 
-def create_address_pivot(df):
+def create_address_pivot(df): # Extraer en un dataframe un json dentro de otro json
 
     aux=pd.json_normalize(df[['linkedin_username','emails']].to_dict(orient='records'),record_path='emails',meta=['linkedin_username'])
     aux['type'].fillna('unknown',inplace=True)
